@@ -598,7 +598,7 @@ gs_plugin_shell_extensions_parse_apps (GsPlugin *plugin,
 	}
 
 	/* load extensions */
-	apps = g_ptr_array_new ();
+	apps = g_ptr_array_new_with_free_func ((GDestroyNotify) g_object_unref);
 	json_extensions = json_object_get_member (json_item, "extensions");
 	if (json_extensions == NULL) {
 		g_set_error_literal (error,
