@@ -41,6 +41,8 @@
 
 #include <langinfo.h>
 
+#define GS_REFRESH_MIN_AGE 10 /* sec */
+
 typedef enum {
 	GS_UPDATES_PAGE_FLAG_NONE		= 0,
 	GS_UPDATES_PAGE_FLAG_HAS_UPDATES	= 1 << 0,
@@ -1077,6 +1079,11 @@ gs_updates_page_get_system_finished_cb (GObject *source_object,
 
 	/* show or hide the end of life notification */
 	app = gs_plugin_loader_get_system_app (plugin_loader);
+	if (app == NULL) {
+		g_warning ("failed to get system app");
+		gtk_widget_set_visible (self->box_end_of_life, FALSE);
+		return;
+	}
 	if (gs_app_get_state (app) != AS_APP_STATE_UNAVAILABLE) {
 		gtk_widget_set_visible (self->box_end_of_life, FALSE);
 		return;
@@ -1270,7 +1277,7 @@ gs_updates_page_get_new_updates (GsUpdatesPage *self)
 	plugin_job = gs_plugin_job_newv (GS_PLUGIN_ACTION_REFRESH,
 					 "failure-flags", GS_PLUGIN_FAILURE_FLAGS_USE_EVENTS,
 					 "refresh-flags", refresh_flags,
-					 "age", (guint64) (10 * 60),
+					 "age", (guint64) GS_REFRESH_MIN_AGE,
 					 NULL);
 	gs_plugin_loader_job_process_async (self->plugin_loader, plugin_job,
 					    self->cancellable_refresh,
